pub struct VirtioPollConfig {
pub gateway_mac: [u8; 6],
pub guest_mac: [u8; 6],
pub gateway_ipv4: Ipv4Addr,
pub guest_ipv4: Ipv4Addr,
pub mtu: usize,
}Expand description
Resolved network parameters for one guest NIC.
These are the host-side parameters for the virtual link. Note that the smoltcp interface is configured with the gateway MAC/IP, because the host runtime is acting as the guest-visible gateway endpoint.
Fields
gateway_mac: [u8; 6]Host-side gateway MAC visible to the guest.
guest_mac: [u8; 6]Guest MAC address.
gateway_ipv4: Ipv4AddrGateway IPv4 address.
guest_ipv4: Ipv4AddrGuest IPv4 address.
mtu: usizeIP-level MTU.