pub struct DeviceTxToken<'a> { /* private fields */ }Expand description
TX token representing one outgoing frame from smoltcp.
The token borrows the device so it can enqueue the produced frame when smoltcp finishes writing into the provided buffer.